@@ -1,5 +1,7 @@
+#!/usr/bin/env perl
+
 # mt-aws-glacier - Amazon Glacier sync client
-# Copyright (C) 2012-2014  Victor Efimov
+# Copyright (C) 2012-2013  Victor Efimov
 # http://mt-aws.com (also http://vs-dev.com) vs@vs-dev.com
 # License: GPLv3
 #
@@ -37,20 +39,19 @@ use warnings;
 use utf8;
 use 5.008008; # minumum perl version is 5.8.8
 
-our $VERSION = '1.114_2';
+our $VERSION = '1.050';
 our $VERSION_MATURITY = "";
 
 use constant ONE_MB => 1024*1024;
 
 use App::MtAws::ParentWorker;
 use App::MtAws::ChildWorker;
-
-use App::MtAws::QueueJob::CreateVault;
-use App::MtAws::QueueJob::DeleteVault;
-use App::MtAws::QueueJob::RetrieveInventory;
-use App::MtAws::QueueJob::FetchAndDownload;
-use App::MtAws::QueueJob::Upload;
-
+use App::MtAws::JobProxy;
+use App::MtAws::Job::FileCreate;
+use App::MtAws::Job::FileListDelete;
+use App::MtAws::Job::RetrievalFetch;
+use App::MtAws::JobListProxy;
+use App::MtAws::Job::RetrieveInventory;
 use File::Find ;
 use File::Spec;
 use App::MtAws::Journal;
@@ -58,7 +59,8 @@ use App::MtAws::ConfigDefinition;
 use App::MtAws::ForkEngine qw/with_forks fork_engine/;
 use Carp;
 use IO::Handle;
-
+use App::MtAws::Job::CreateVault;
+use App::MtAws::Job::DeleteVault;
 use App::MtAws::Utils;
 use App::MtAws::Exceptions;
 use PerlIO::encoding;
@@ -83,7 +85,7 @@ sub print_system_modules_version
 			my $name = $module;
 			$name =~ s[/][::]g;
 			$name =~ s[\.pmc?$][];
-			my $ver = eval qq{\$${name}::VERSION};
+			my $ver = $name->VERSION;
 			$ver = 'undef' unless defined $ver;
 			print "$name\t$ver\t$INC{$module}\n";
 		}
@@ -92,30 +94,16 @@ sub print_system_modules_version
 
 sub load_all_dynamic_modules
 {
+	# we load here all dynamically loaded modules, to check that installation is correct.
 	require App::MtAws::Command::Sync;
 	require App::MtAws::Command::Retrieve;
 	require App::MtAws::Command::CheckLocalHash;
 	require App::MtAws::Command::DownloadInventory;
-}
-
-sub check_all_dynamic_modules
-{
-	# we load here all dynamically loaded modules, to check that installation is correct.
-	load_all_dynamic_modules();
 	check_module_versions;
 }
 
 sub main
 {
-	$|=1;
-	STDERR->autoflush(1);
-	print "MT-AWS-Glacier, Copyright 2012-2014 Victor Efimov http://mt-aws.com/ Version $VERSION$VERSION_MATURITY\n\n";
-
-	warn "**NOT RECOMMENDED FOR PRODUCTION USE UNDER CYGWIN**\n\n" if ($^O eq 'cygwin');
-	die "**DEVELOPMENT VERSION, NOT FOR PRODUCTION USE. EXITING**\n\n" if ($VERSION =~ /_/);
-	warn "**NOT TESTED UNDER PERLIO=stdio**\n\n" if (defined $ENV{PERLIO} && $ENV{PERLIO} =~ /stdio/);
-	die "Will *not* work under Win32\n" if ($^O eq 'MSWin32');
-
 	check_module_versions();
 	unless (defined eval {process(); 1;}) {
 		dump_error(q{});
@@ -127,6 +115,10 @@ sub main
 
 sub process
 {
+	$|=1;
+	STDERR->autoflush(1);
+	print "MT-AWS-Glacier, Copyright 2012-2013 Victor Efimov http://mt-aws.com/ Version $VERSION$VERSION_MATURITY\n\n";
+
 	my ($P) = @_;
 	my ($src, $vault, $journal);
 	my $maxchildren = 4;
@@ -179,7 +171,7 @@ sub process
 
 			## no Test::Tabs
 			die <<"END"
-File with same name already exists in Journal.
+File with same name alredy exists in Journal.
 In the current version of mtglacier you are disallowed to store multiple versions of same file.
 Multiversion will be implemented in the future versions.
 END
@@ -194,12 +186,14 @@ END
 			$j->open_for_write();
 
 			my $ft = ($options->{'data-type'} eq 'filename') ?
-				App::MtAws::QueueJob::Upload->new(
-					filename => $options->{filename}, relfilename => $relfilename,
-					partsize => ONE_MB*$partsize, delete_after_upload => 0) :
-				App::MtAws::QueueJob::Upload->new(
-					stdin => 1, relfilename => $relfilename,
-					partsize => ONE_MB*$partsize, delete_after_upload => 0);
+				App::MtAws::JobProxy->new(job => App::MtAws::Job::FileCreate->new(
+					filename => $options->{filename},
+					relfilename => $relfilename,
+					partsize => ONE_MB*$partsize)) :
+				App::MtAws::JobProxy->new(job => App::MtAws::Job::FileCreate->new(
+					stdin => 1,
+					relfilename => $relfilename,
+					partsize => ONE_MB*$partsize));
 
 			my ($R) = fork_engine->{parent_worker}->process_task($ft, $j);
 			die unless $R;
@@ -219,20 +213,10 @@ END
 					}
 				} else {
 					$j->open_for_write();
-
 					my @filelist = map { {archive_id => $_, relfilename =>$archives->{$_}->{relfilename} } } keys %{$archives};
-					my $ft = App::MtAws::QueueJob::Iterator->new(iterator => sub {
-						if (my $rec = shift @filelist) {
-							return App::MtAws::QueueJob::Delete->new(
-								relfilename => $rec->{relfilename}, archive_id => $rec->{archive_id},
-							);
-						} else {
-							return;
-						}
-					});
+					my $ft = App::MtAws::JobProxy->new(job => App::MtAws::Job::FileListDelete->new(archives => \@filelist ));
 					my ($R) = fork_engine->{parent_worker}->process_task($ft, $j);
 					die unless $R;
-
 					$j->close_for_write();
 				}
 			} else {
@@ -267,11 +251,11 @@ END
 				keys %{$files};
 			if (keys %filelist) {
 				if ($options->{'dry-run'}) {
-					for (values %filelist) {
-						print "Will DOWNLOAD (if available) archive $_->{archive_id} (filename $_->{relfilename})\n";
+					for (keys %filelist) {
+						print "Will DOWNLOAD (if available) archive $_->{archive_id} (filename $_->{relfilename})\n" for ($j->latest($_));
 					}
 				} else {
-					my $ft = App::MtAws::QueueJob::FetchAndDownload->new(file_downloads => $options->{file_downloads}||{}, archives => \%filelist);
+					my $ft = App::MtAws::JobProxy->new(job => App::MtAws::Job::RetrievalFetch->new(file_downloads => $options->{file_downloads}, archives => \%filelist ));
 					my ($R) = fork_engine->{parent_worker}->process_task($ft, $j);
 					die unless $R;
 				}
@@ -288,7 +272,7 @@ END
 		$options->{concurrency} = 1; # TODO implement this in ConfigEngine
 
 		with_forks 1, $options, sub {
-			my $ft = App::MtAws::QueueJob::RetrieveInventory->new(format => $options->{'request-inventory-format'});
+			my $ft = App::MtAws::JobProxy->new(job => App::MtAws::Job::RetrieveInventory->new());
 			my ($R) = fork_engine->{parent_worker}->process_task($ft, undef);
 		}
 	} elsif ($action eq 'download-inventory') {
@@ -301,14 +285,14 @@ END
 		$options->{concurrency} = 1;
 
 		with_forks 1, $options, sub {
-			my $ft = App::MtAws::QueueJob::CreateVault->new(name => $options->{'vault-name'});
+			my $ft = App::MtAws::JobProxy->new(job => App::MtAws::Job::CreateVault->new(name => $options->{'vault-name'}));
 			my ($R) = fork_engine->{parent_worker}->process_task($ft, undef);
 		}
 	} elsif ($action eq 'delete-vault') {
 		$options->{concurrency} = 1;
 
 		with_forks 1, $options, sub {
-			my $ft = App::MtAws::QueueJob::DeleteVault->new(name => $options->{'vault-name'});
+			my $ft = App::MtAws::JobProxy->new(job => App::MtAws::Job::DeleteVault->new(name => $options->{'vault-name'}));
 			my ($R) = fork_engine->{parent_worker}->process_task($ft, undef);
 		}
 	} elsif ($action eq 'help') {
@@ -341,7 +325,6 @@ Commands:
 	  --segment-size - Size for multi-segment download, in megabytes
 	check-local-hash
 	retrieve-inventory
-	  --request-inventory-format - json or csv
 	download-inventory
 	  --new-journal - Write inventory as new journal
 	create-vault VAULT-NAME
@@ -364,7 +347,7 @@ END
 ## use Test::Tabs
 
 	} elsif ($action eq 'version') {
-		check_all_dynamic_modules();
+		load_all_dynamic_modules();
 		print "mt-aws-glacier version: $VERSION $VERSION_MATURITY\n";
 		print "Perl Version: $]\n";
 		print_system_modules_version();
