@@ -1,5 +1,5 @@
 # mt-aws-glacier - Amazon Glacier sync client
-# Copyright (C) 2012-2014  Victor Efimov
+# Copyright (C) 2012-2013  Victor Efimov
 # http://mt-aws.com (also http://vs-dev.com) vs@vs-dev.com
 # License: GPLv3
 #
@@ -20,7 +20,7 @@
 
 package App::MtAws::ChildWorker;
 
-our $VERSION = '1.114_2';
+our $VERSION = '1.050';
 
 use App::MtAws::LineProtocol;
 use App::MtAws::GlacierRequest;
@@ -50,14 +50,17 @@ sub process
 
 	my $tochild = $self->{tochild};
 	my $fromchild = $self->{fromchild};
-	while (1) {
-		my ($remote_pid, $action, $taskid, $data, $attachmentref) = get_data($tochild);
-		$remote_pid or comm_error(); # we exit() if eof or socket error. we don't distinct
-		my ($result, $result_attachmentref, $console_out) = $self->process_task($action, $data, $attachmentref);
-		$result->{console_out}=$console_out;
-		send_data($fromchild, 'response', $taskid, $result, $result_attachmentref) or comm_error();
-	};
-	# unreachable
+	my $disp_select = IO::Select->new();
+	$disp_select->add($tochild);
+	do { while (my @ready = $disp_select->can_read()) {
+		for my $fh (@ready) {
+			my ($remote_pid, $action, $taskid, $data, $attachmentref) = get_data($fh);
+			$remote_pid or comm_error();
+			my ($result, $result_attachmentref, $console_out) = $self->process_task($action, $data, $attachmentref);
+			$result->{console_out}=$console_out;
+			send_data($fromchild, 'response', $taskid, $result, $result_attachmentref) or comm_error();
+		}
+	} } until $! != EINTR;
 }
 
 sub process_task
@@ -133,11 +136,11 @@ sub process_task
 		$console_out = "Downloaded part of archive $data->{filename} at offset $data->{position}, size $data->{download_size}";
 	} elsif ($action eq 'inventory_download_job') {
 		my $req = App::MtAws::GlacierRequest->new($self->{options});
-		my ($r, $inventory_type) = $req->retrieval_download_to_memory($data->{job_id});
+		my $r = $req->retrieval_download_to_memory($data->{job_id});
 		confess "inventory_download_job failed" unless $r;
-		$result = { response => !! $r, inventory_type => $inventory_type };
+		$result = { response => !! $r };
 		$result_attachmentref = \$r;
-		$console_out = "Downloaded inventory in ".($inventory_type eq INVENTORY_TYPE_JSON ? "JSON" : "CSV")." format";
+		$console_out = "Downloaded inventory in JSON format";
 	} elsif ($action eq 'retrieve_archive') {
 		my $req = App::MtAws::GlacierRequest->new($self->{options});
 		my $r = $req->retrieve_archive( $data->{archive_id});
@@ -165,7 +168,7 @@ sub process_task
 		$console_out = "Fetched job list for inventory retrieval";
 	} elsif ($action eq 'retrieve_inventory_job') {
 		my $req = App::MtAws::GlacierRequest->new($self->{options});
-		my $r = $req->retrieve_inventory($data->{format});
+		my $r = $req->retrieve_inventory();
 		confess unless $r;
 		$result = { job_id => $r };
 		$console_out = "Retrieved Inventory, job id $r";
