@@ -1,5 +1,5 @@
 # mt-aws-glacier - Amazon Glacier sync client
-# Copyright (C) 2012-2014  Victor Efimov
+# Copyright (C) 2012-2013  Victor Efimov
 # http://mt-aws.com (also http://vs-dev.com) vs@vs-dev.com
 # License: GPLv3
 #
@@ -20,7 +20,7 @@
 
 package App::MtAws::Command::DownloadInventory;
 
-our $VERSION = '1.114_2';
+our $VERSION = '1.050';
 
 use strict;
 use warnings;
@@ -31,31 +31,25 @@ use App::MtAws::ForkEngine  qw/with_forks fork_engine/;
 use App::MtAws::TreeHash;
 use App::MtAws::Exceptions;
 use App::MtAws::Journal;
-use App::MtAws::MetaData;
-use App::MtAws::DateTime;
-use App::MtAws::Glacier::Inventory::JSON;
-use App::MtAws::Glacier::Inventory::CSV;
-
-use App::MtAws::QueueJob::FetchAndDownloadInventory;
+use App::MtAws::Job::InventoryFetch;
 
 sub run
 {
 	my ($options, $j) = @_;
 	with_forks 1, $options, sub {
 
-		my $ft =  App::MtAws::QueueJob::FetchAndDownloadInventory->new();
-		my ($R) = fork_engine->{parent_worker}->process_task($ft, undef);
-		my $attachmentref = $R->{inventory_raw_ref};
-		my $inventory_type = $R->{inventory_type};
-
+		my $ft = App::MtAws::JobProxy->new(job => App::MtAws::Job::InventoryFetch->new());
+		my ($R, $attachmentref) = fork_engine->{parent_worker}->process_task($ft, undef);
 		# here we can have response from both JobList or Inventory output..
 		# JobList looks like 'response' => '{"JobList":[],"Marker":null}'
 		# Inventory retriebal has key 'ArchiveList'
 		# TODO: implement it more clear way on level of Job/Tasks object
+
 		croak if -s binaryfilename $options->{'new-journal'}; # TODO: fix race condition between this and opening file
-		if ($R && $attachmentref) { # $attachmentref can be SCALAR REF or can be undef
+
+		if ($R && $attachmentref) {
 			$j->open_for_write();
-			parse_and_write_journal($j, $inventory_type, $attachmentref);
+			parse_and_write_journal($j, $attachmentref);
 			$j->close_for_write();
 		}
 	}
@@ -63,22 +57,13 @@ sub run
 
 sub parse_and_write_journal
 {
-	my ($j, $inventory_type, $attachmentref) = @_;
-	my $data = do {
-		if ($inventory_type eq INVENTORY_TYPE_JSON) {
-			App::MtAws::Glacier::Inventory::JSON->new($$attachmentref)
-		} elsif ($inventory_type eq INVENTORY_TYPE_CSV) {
-			App::MtAws::Glacier::Inventory::CSV->new($$attachmentref)
-		} else {
-			confess "unknown inventory type $inventory_type";
-		}
-	}->get_archives();
-
-	for my $item (@$data) {
+	my ($j, $attachmentref) = @_;
+	my $data = JSON::XS->new->allow_nonref->utf8->decode($$attachmentref);
+	for my $item (@{$data->{'ArchiveList'}}) {
 		my ($relfilename, $mtime) = App::MtAws::MetaData::meta_decode($item->{ArchiveDescription});
 		$relfilename = $item->{ArchiveId} unless defined $relfilename;
 
-		my $creation_time = iso8601_to_epoch($item->{CreationDate}); # TODO: move code out
+		my $creation_time = App::MtAws::MetaData::_parse_iso8601($item->{CreationDate}); # TODO: move code out
 		#time archive_id size mtime treehash relfilename
 		$j->add_entry({
 			type => 'CREATED',
