@@ -1,5 +1,5 @@
 # mt-aws-glacier - Amazon Glacier sync client
-# Copyright (C) 2012-2014  Victor Efimov
+# Copyright (C) 2012-2013  Victor Efimov
 # http://mt-aws.com (also http://vs-dev.com) vs@vs-dev.com
 # License: GPLv3
 #
@@ -20,7 +20,7 @@
 
 package App::MtAws::Command::Retrieve;
 
-our $VERSION = '1.114_2';
+our $VERSION = '1.050';
 
 use strict;
 use warnings;
@@ -28,19 +28,7 @@ use utf8;
 use Carp;
 use App::MtAws::ForkEngine qw/with_forks fork_engine/;
 use App::MtAws::Utils;
-
-use App::MtAws::QueueJob::Retrieve;
-use App::MtAws::QueueJob::Iterator;
-
-sub next_retrieve
-{
-	my ($filelistref) = @_;
-	if (my $rec = shift @{ $filelistref }) {
-		return App::MtAws::QueueJob::Retrieve->new(map { $_ => $rec->{$_}} qw/archive_id filename relfilename/ );
-	} else {
-		return;
-	}
-}
+use App::MtAws::Job::FileListRetrieval;
 
 sub run
 {
@@ -57,8 +45,8 @@ sub run
 					print "Will RETRIEVE archive $_->{archive_id} (filename $_->{relfilename})\n"
 				}
 			} else {
-				my $ft = App::MtAws::QueueJob::Iterator->new(iterator => sub { next_retrieve(\@filelist) });
 				$j->open_for_write();
+				my $ft = App::MtAws::JobProxy->new(job => App::MtAws::Job::FileListRetrieval->new(archives => \@filelist ));
 				my ($R) = fork_engine->{parent_worker}->process_task($ft, $j);
 				die unless $R;
 				$j->close_for_write();
@@ -69,7 +57,7 @@ sub run
 	}
 }
 
-sub get_file_list # TODO: optimize as lazy code
+sub get_file_list
 {
 	my ($options, $j) = @_;
 	my $files = $j->{journal_h};
