@@ -1,5 +1,5 @@
 # mt-aws-glacier - Amazon Glacier sync client
-# Copyright (C) 2012-2014  Victor Efimov
+# Copyright (C) 2012-2013  Victor Efimov
 # http://mt-aws.com (also http://vs-dev.com) vs@vs-dev.com
 # License: GPLv3
 #
@@ -20,7 +20,7 @@
 
 package App::MtAws::Command::Sync;
 
-our $VERSION = '1.114_2';
+our $VERSION = '1.050';
 
 use strict;
 use warnings;
@@ -32,11 +32,12 @@ use constant SHOULD_CREATE => 1;
 use constant SHOULD_TREEHASH => 2;
 use constant SHOULD_NOACTION => 0;
 
-use App::MtAws::QueueJob::Iterator;
-use App::MtAws::QueueJob::VerifyAndUpload;
-use App::MtAws::QueueJob::Upload;
-use App::MtAws::QueueJob::Delete;
-
+use App::MtAws::JobProxy;
+use App::MtAws::JobListProxy;
+use App::MtAws::JobIteratorProxy;
+use App::MtAws::Job::FileCreate;
+use App::MtAws::Job::FileListDelete;
+use App::MtAws::Job::FileVerifyAndUpload;
 use App::MtAws::ForkEngine  qw/with_forks fork_engine/;
 use App::MtAws::Journal;
 use App::MtAws::Utils;
@@ -90,18 +91,22 @@ sub next_modified
 		my $should_upload = should_upload($options, $file, $absfilename);
 
 		if ($should_upload == SHOULD_TREEHASH) {
-			return App::MtAws::QueueJob::VerifyAndUpload->new(
-				filename => $absfilename, relfilename => $relfilename, partsize => ONE_MB*$options->{partsize},
-				delete_after_upload => 1,
-				archive_id => $file->{archive_id},
-				treehash => $file->{treehash}
-			);
+			return App::MtAws::JobProxy->new(job=>
+				App::MtAws::Job::FileVerifyAndUpload->new(filename => $absfilename,
+					relfilename => $relfilename, partsize => ONE_MB*$options->{partsize},
+					delete_after_upload => 1,
+					archive_id => $file->{archive_id},
+					treehash => $file->{treehash}
+			));
 		} elsif ($should_upload == SHOULD_CREATE) {
-			return App::MtAws::QueueJob::Upload->new(
+			return App::MtAws::JobProxy->new(job=> App::MtAws::Job::FileCreate->new(
 				filename => $absfilename, relfilename => $relfilename, partsize => ONE_MB*$options->{partsize},
-				delete_after_upload => 1,
-				archive_id => $file->{archive_id},
-			);
+				(finish_cb => sub {
+					App::MtAws::Job::FileListDelete->new(archives => [{
+						archive_id => $file->{archive_id}, relfilename => $relfilename
+					}])
+				})
+			));
 		} elsif ($should_upload == SHOULD_NOACTION) {
 			next;
 		} else {
@@ -115,10 +120,9 @@ sub next_missing
 {
 	my ($options, $j) = @_;
 	if (my $rec = shift @{ $j->{listing}{missing} }) {
-		return App::MtAws::QueueJob::Delete->new(
-			relfilename => $rec->{relfilename},
-			archive_id => $j->latest($rec->{relfilename})->{archive_id},
-		);
+		App::MtAws::Job::FileListDelete->new(archives => [{
+			archive_id => $j->latest($rec->{relfilename})->{archive_id}, relfilename => $rec->{relfilename}
+		}]);
 	} else {
 		return;
 	}
@@ -129,7 +133,8 @@ sub next_new
 	my ($options, $j) = @_;
 	if (my $rec = shift @{ $j->{listing}{new} }) {
 		my ($absfilename, $relfilename) = ($j->absfilename($rec->{relfilename}), $rec->{relfilename});
-		App::MtAws::QueueJob::Upload->new(filename => $absfilename, relfilename => $relfilename, partsize => ONE_MB*$options->{partsize}, delete_after_upload => 0);
+		App::MtAws::JobProxy->new(job =>
+			App::MtAws::Job::FileCreate->new(filename => $absfilename, relfilename => $relfilename, partsize => ONE_MB*$options->{partsize}));
 	} else {
 		return;
 	}
@@ -173,7 +178,7 @@ sub run
 			if ($options->{'dry-run'}) {
 				print_dry_run($itt);
 			} else {
-				push @joblist, App::MtAws::QueueJob::Iterator->new(iterator => $itt);
+				push @joblist, App::MtAws::JobIteratorProxy->new(iterator => $itt);
 			}
 		}
 
@@ -183,7 +188,7 @@ sub run
 			if ($options->{'dry-run'}) {
 				print_dry_run($itt);
 			} else {
-				push @joblist, App::MtAws::QueueJob::Iterator->new(iterator => $itt);
+				push @joblist, App::MtAws::JobIteratorProxy->new(iterator => $itt);
 			}
 		}
 		if ($options->{'delete-removed'}) {
@@ -191,15 +196,12 @@ sub run
 			if ($options->{'dry-run'}) {
 				print_dry_run($itt);
 			} else {
-				push @joblist, App::MtAws::QueueJob::Iterator->new(iterator => $itt);
+				push @joblist, App::MtAws::JobIteratorProxy->new(iterator => $itt);
 			}
 		}
 
 		if (scalar @joblist) {
-			my $lt = do {
-				confess unless @joblist >= 1;
-				App::MtAws::QueueJob::Iterator->new(iterator => sub { shift @joblist });
-			};
+			my $lt = App::MtAws::JobListProxy->new(jobs => \@joblist);
 			my ($R) = fork_engine->{parent_worker}->process_task($lt, $j);
 			confess unless $R;
 		}
