@@ -1,5 +1,5 @@
 # mt-aws-glacier - Amazon Glacier sync client
-# Copyright (C) 2012-2014  Victor Efimov
+# Copyright (C) 2012-2013  Victor Efimov
 # http://mt-aws.com (also http://vs-dev.com) vs@vs-dev.com
 # License: GPLv3
 #
@@ -20,7 +20,7 @@
 
 package App::MtAws::ConfigDefinition;
 
-our $VERSION = "1.114_2";
+our $VERSION = "1.050";
 
 use strict;
 use warnings;
@@ -101,35 +101,14 @@ sub check_dir_or_relname
 				custom('relfilename', do {
 					validate 'dir', 'filename';
 					if (valid('dir') && valid('filename')) {
-
-						my $b_dir = binary_abs_path(binaryfilename value('dir'));
-						my $b_file = binary_abs_path(binaryfilename value('filename'));
-
-						if (!defined $b_dir) {
-							error(message('cannot_resolve_dir',
-								'Directory specified with "%option a%" cannot be resolved to full path'),
-								a => 'dir'), undef
-						} elsif (!defined $b_file) {
-							error(message('cannot_resolve_file',
-								'File specified with "%option a%" cannot be resolved to full path'),
-								a => 'filename'), undef;
+						my $relfilename = File::Spec->abs2rel(value('filename'), value('dir'));
+						if ($relfilename =~ m!^\.\./!) {
+							error(message('filename_inside_dir',
+								'File specified with "option a" should be inside directory specified in %option b%'),
+								a => 'filename', b => 'dir'),
+							undef;
 						} else {
-							my $relfilename = characterfilename abs2rel($b_file, $b_dir, allow_rel_base => 0, use_filename_encoding => 0);
-
-							my $dir = value('dir');
-							$dir =~ s!/$!!; # just in case
-
-							confess "something wrong with relative-absolute paths"
-								unless file_inodev(value('filename')) eq file_inodev($dir."/".$relfilename);
-
-							if (!is_relative_filename($relfilename)) {
-								error(message('filename_inside_dir',
-									'File specified with "option a" should be inside directory specified in %option b%'),
-									a => 'filename', b => 'dir'),
-								undef;
-							} else {
-								$relfilename
-							}
+							$relfilename
 						}
 					} else {
 						undef;
@@ -207,9 +186,9 @@ sub check_https
 	if (present('protocol') and value('protocol') eq 'https') {
 		if (LWP::UserAgent->is_protocol_supported("https")) {
 			# to get LWP version, use LWP->VERSION instead of LWP::UserAgent->VERSION
-			error('LWP::UserAgent 6.x required to use HTTPS') unless LWP->VERSION() ge '6';
+			error('LWP::UserAgent 6.x required to use HTTPS') unless LWP->VERSION() >= 6;
 			require LWP::Protocol::https;
-			error('LWP::Protocol::https 6.x required to use HTTPS') unless LWP::Protocol::https->VERSION && LWP::Protocol::https->VERSION ge '6';
+			error('LWP::Protocol::https 6.x required to use HTTPS') unless LWP::Protocol::https->VERSION && LWP::Protocol::https->VERSION >= 6;
 		} else {
 			error('IO::Socket::SSL or LWP::Protocol::https is not installed');
 		}
@@ -220,9 +199,9 @@ sub check_https
 sub check_max_size
 {
 	if (present('check-max-file-size')) {
-		if (value('check-max-file-size') > 10_000 * value('partsize')) {
+		if (value('check-max-file-size')/value('partsize') > 10_000) {
 			seen('check-max-file-size'), error(message('partsize_vs_maxsize',
-				"With current partsize %d partsizevalue%MiB and maximum allowed file size %d maxsizevalue%MiB, upload might exceed 10 000 parts. ".
+				"With current partsize %d partsizevalue%MiB and maximum allowed file size %d maxsizevalue%MiB, upload might exceed 10 000 parts.".
 				"Increase %option partsize% or decrease %option maxsize%"),
 				partsize => 'partsize', maxsize => 'check-max-file-size', partsizevalue => value('partsize'), maxsizevalue => value('check-max-file-size'));
 		} else {
@@ -318,6 +297,8 @@ sub get_config
 		my $invalid_format = message('invalid_format', 'Invalid format of "%a%"');
 		my $must_be_an_integer = message('must_be_an_integer', '%option a% must be positive integer number');
 
+
+
 		option('new', type=>'');
 		option('replace-modified', type=>'');
 		option('delete-removed', type=>'');
@@ -348,23 +329,18 @@ sub get_config
 		for (option('check-max-file-size', type => 'i')) {
 			validation $_, $must_be_an_integer, stop => 1, sub { $_ =~ /^\d+$/ };
 			validation $_, message('check-max-file-size should be greater than 0'), stop => 1, sub { $_ > 0 }; # TODO: %option .. %
-			validation $_, message('maxsize_too_big', '%option a% should be less than or equal to 40960000 (and you have %value%)'),
-				stop => 1, sub { $_ <= 10_000 * 4096 };
+			validation $_, message('check-max-file-size should be less than or equal to 40 000 000'), stop => 1, sub { $_ <= 40_000_000 };
 		}
 
 		for (option('partsize', type => 'i', default => 16)) {
 			validation $_, $must_be_an_integer, stop => 1, sub { $_ =~ /^\d+$/ };
 			validation $_, message('Part size must be power of two'), sub { ($_ != 0) && (($_ & ($_ - 1)) == 0) };
-			validation $_, message('%option a% must be less or equal to 4096'), sub { $_ <= 4096 };
 		}
 		for (option('segment-size', type => 'i')) {
 			validation $_, $must_be_an_integer, stop => 1, sub { $_ =~ /^\d+$/ };
 			validation $_, message('%option a% must be zero or power of two'), sub { (($_ & ($_ - 1)) == 0) }; # TODO: proper format
 		}
 
-		validation(option('request-inventory-format', default => 'json'),
-			message('request-inventory-format must be "json" or "csv"'), sub { /^(json|csv)$/ });
-
 		validation positional('vault-name'), message('Vault name should be 255 characters or less and consisting of a-z, A-Z, 0-9, ".", "-", and "_"'), sub {
 			/^[A-Za-z0-9\.\-_]{1,255}$/
 		};
@@ -418,7 +394,7 @@ sub get_config
 		};
 
 		command 'retrieve-inventory' => sub {
-			validate(mandatory(optional('config'), mandatory(@encodings), 'request-inventory-format', @config_opts, check_https, qw/vault/))
+			validate(mandatory(optional('config'), mandatory(@encodings), @config_opts, check_https, qw/vault/))
 		};
 
 		command 'download-inventory' => sub {
