@@ -1,5 +1,5 @@
 # mt-aws-glacier - Amazon Glacier sync client
-# Copyright (C) 2012-2014  Victor Efimov
+# Copyright (C) 2012-2013  Victor Efimov
 # http://mt-aws.com (also http://vs-dev.com) vs@vs-dev.com
 # License: GPLv3
 #
@@ -20,7 +20,7 @@
 
 package App::MtAws::ConfigEngine;
 
-our $VERSION = '1.114_2';
+our $VERSION = '1.050';
 
 use Getopt::Long 2.24 qw/:config no_ignore_case/ ;
 use Encode;
@@ -32,7 +32,8 @@ use utf8;
 use App::MtAws::Exceptions;
 use App::MtAws::Utils;
 
-use Exporter 'import';
+require Exporter;
+use base qw/Exporter/;
 
 our @EXPORT = qw/option options positional command validation message
 	mandatory optional seen deprecated validate scope
@@ -522,7 +523,7 @@ sub deprecated(@)
 		my $opt = $context->{options}->{ seen() };
 		confess "positional options can't be deprecated" if $opt->{positional};
 		if (defined $opt->{value}) {
-			warning('option_deprecated_for_command', a => _real_option_name $opt) if $opt->{source} eq 'option';
+			warning('option_deprecated_for_command', a => _real_option_name $opt);
 			undef $opt->{value};
 		}
 		$_;
