@@ -1,5 +1,5 @@
 # mt-aws-glacier - Amazon Glacier sync client
-# Copyright (C) 2012-2014  Victor Efimov
+# Copyright (C) 2012-2013  Victor Efimov
 # http://mt-aws.com (also http://vs-dev.com) vs@vs-dev.com
 # License: GPLv3
 #
@@ -20,7 +20,7 @@
 
 package App::MtAws::Exceptions;
 
-our $VERSION = '1.114_2';
+our $VERSION = '1.050';
 
 use strict;
 use warnings;
@@ -32,7 +32,8 @@ use App::MtAws::Utils;
 use Carp;
 eval { require I18N::Langinfo; }; # TODO: test that it's loaded compile time, test that it wont break if failed
 
-use Exporter 'import';
+require Exporter;
+use base qw/Exporter/;
 
 
 our @EXPORT = qw/exception get_exception is_exception exception_message dump_error get_errno/;
