@@ -1,5 +1,5 @@
 # mt-aws-glacier - Amazon Glacier sync client
-# Copyright (C) 2012-2014  Victor Efimov
+# Copyright (C) 2012-2013  Victor Efimov
 # http://mt-aws.com (also http://vs-dev.com) vs@vs-dev.com
 # License: GPLv3
 #
@@ -20,7 +20,7 @@
 
 package App::MtAws::ForkEngine;
 
-our $VERSION = '1.114_2';
+our $VERSION = '1.050';
 
 use strict;
 use warnings;
@@ -35,7 +35,8 @@ use App::MtAws::Utils;
 use App::MtAws::Exceptions;
 use POSIX;
 
-use Exporter 'import';
+require Exporter;
+use base qw/Exporter/;
 
 our @EXPORT_OK = qw/with_forks fork_engine/;
 
@@ -96,21 +97,8 @@ sub run_parent
 
 sub parent_exit_on_signal
 {
-	my ($self, $sig, $status) = @_;
-	my $status_str = do {
-		if (defined $status) {
-			my $exit_code = $status >> 8;
-			my $signal = $status & 127;
-			if ($signal) {
-				" (signal $signal, exit_code $exit_code)";
-			} else {
-				" (exit_code $exit_code)";
-			}
-		} else {
-			"";
-		}
-	};
-	print STDERR "\nEXIT on SIG$sig$status_str\n";
+	my ($self, $sig, $children) = @_;
+	print STDERR "\nEXIT on SIG$sig\n";
 	exit(1);
 }
 
@@ -144,19 +132,17 @@ sub start_children
 	for my $sig (qw/INT TERM CHLD USR1 HUP/) {
 		$SIG{$sig} = sub {
 			local ($!,$^E,$@);
-			my $status = undef;
 			if ($sig eq 'CHLD') {
 				my $pid = waitpid(-1, WNOHANG);
-				$status = $?;
 				# make sure we caugth signal from our children, not from external command executionin 3rd party module
 				# easy to test by adding `whoami` to parent after-fork-code
-				return unless $pid > 0 and defined delete $self->{children}{$pid}; # we also remove $pid
+				return unless $pid > 0 and defined $self->{children}{$pid};
 			}
 			if ($first_time) {
 				$first_time = 0;
 				kill (POSIX::SIGUSR2, keys %{$self->{children}});
 				while( wait() != -1 ){};
-				$self->parent_exit_on_signal($sig, $status);
+				$self->parent_exit_on_signal($sig, $self->{children});
 			}
 		};
 	}
@@ -224,13 +210,6 @@ sub terminate_children
 	my ($self) = @_;
 	$SIG{CHLD} = 'DEFAULT'; # don't set SIGCHLD to IGNORE, prevents wait() from working under 5.12.2,3 undef OpenBSD
 	$SIG{INT} = $SIG{USR2}='IGNORE';
-
-	# close all pipes, just in case select() in child is not interruptable (seems it is under 5.14.2?)
-	# https://rt.perl.org/Ticket/Display.html?id=93428
-	for (values %{$self->{children}}) {
-		close $_->{fromchild};
-		close $_->{tochild};
-	}
 	kill (POSIX::SIGUSR2, keys %{$self->{children}}); # TODO: we terminate all children with SIGUSR2 even on normal exit
 	$SIG{TERM} = 'DEFAULT';
 	while( wait() != -1 ){};
