@@ -1,5 +1,5 @@
 # mt-aws-glacier - Amazon Glacier sync client
-# Copyright (C) 2012-2014  Victor Efimov
+# Copyright (C) 2012-2013  Victor Efimov
 # http://mt-aws.com (also http://vs-dev.com) vs@vs-dev.com
 # License: GPLv3
 #
@@ -20,7 +20,7 @@
 
 package App::MtAws::GlacierRequest;
 
-our $VERSION = '1.114_2';
+our $VERSION = '1.050';
 
 use strict;
 use warnings;
@@ -29,14 +29,15 @@ use POSIX;
 use LWP 5.803;
 use LWP::UserAgent;
 use HTTP::Request;
-use Digest::SHA qw/hmac_sha256 hmac_sha256_hex sha256_hex/;
+use Digest::SHA qw/hmac_sha256 hmac_sha256_hex sha256_hex sha256/;
 use App::MtAws::MetaData;
 use App::MtAws::Utils;
 use App::MtAws::Exceptions;
 use App::MtAws::HttpSegmentWriter;
-use App::MtAws::SHAHash qw/large_sha256_hex/;
 use Carp;
 
+
+
 sub new
 {
 	my ($class, $options) = @_;
@@ -82,10 +83,9 @@ sub create_multipart_upload
 	# currently meat_encode only returns undef if filename is too big
 	defined($self->{description} = App::MtAws::MetaData::meta_encode($relfilename, $mtime)) or
 		die exception 'file_name_too_big' =>
-		"Either relative filename %string filename% is too big to store in Amazon Glacier metadata. ".
-		"(Limit is about 700 ASCII characters or 350 2-byte UTF-8 characters) or file modification time %string mtime% out of range".
-		"(Only years from 1000 to 9999 are supported)",
-		filename => $relfilename, mtime => $mtime; # TODO: more clear error
+		"Relative filename %string filename% is too big to store in Amazon Glacier metadata. ".
+		"Limit is about 700 ASCII characters or 350 2-byte UTF-8 character.",
+		filename => $relfilename;
 	$self->add_header('x-amz-archive-description', $self->{description});
 
 	my $resp = $self->perform_lwp();
@@ -177,31 +177,18 @@ END
 
 sub retrieve_inventory
 {
-	my ($self, $format) = @_;
-
-	$format or confess;
-
-	if ($format eq 'json') {
-		$format = 'JSON';
-	} elsif ($format eq 'csv') {
-		$format = 'CSV';
-	} else {
-		confess "unknown inventory format $format";
-	}
+	my ($self) = @_;
 
 	$self->add_header('Content-Type', 'application/x-www-form-urlencoded; charset=utf-8');
 	$self->{url} = "/$self->{account_id}/vaults/$self->{vault}/jobs";
 	$self->{method} = 'POST';
 
-	my $job_meta = App::MtAws::MetaData::meta_job_encode(META_JOB_TYPE_FULL);
-
 	#  add "SNSTopic": "sometopic"
 	# no Test::Tabs
 	my $body = <<"END";
 {
   "Type": "inventory-retrieval",
-  "Description": "$job_meta",
-  "Format": "$format"
+  "Format": "JSON"
 }
 END
 	# use Test::Tabs
@@ -320,18 +307,7 @@ sub retrieval_download_to_memory
 	my $resp = $self->perform_lwp();
 
 	$resp or confess;
-
-	my $itype = do {
-		my $ct = $resp->content_type;
-		if ($ct eq 'text/csv') {
-			INVENTORY_TYPE_CSV
-		} elsif ($ct eq 'application/json') {
-			INVENTORY_TYPE_JSON
-		} else {
-			confess "Unknown mime-type $ct";
-		}
-	};
-	return ($resp->content, $itype);
+	return $resp->content;
 }
 
 sub create_vault
@@ -369,7 +345,7 @@ sub _calc_data_hash
 	if (length(${$self->{dataref}}) <= 1048576) {
 		$self->{data_sha256} = $self->{part_final_hash};
 	} else {
-		$self->{data_sha256} = large_sha256_hex(${$self->{dataref}});
+		$self->{data_sha256} = sha256_hex(${$self->{dataref}});
 	}
 }
 
@@ -401,7 +377,7 @@ sub _sign
 
 	my $bodyhash = $self->{data_sha256} ?
 		$self->{data_sha256} :
-		( $self->{dataref} ? large_sha256_hex(${$self->{dataref}}) : sha256_hex('') );
+		( $self->{dataref} ? sha256_hex(${$self->{dataref}}) : sha256_hex('') );
 
 	$self->{params_s} = $self->{params} ? join ('&', map { "$_=$self->{params}->{$_}" } sort keys %{$self->{params}}) : ""; # TODO: proper URI encode
 	my $canonical_query_string = $self->{params_s};
