@@ -1,5 +1,5 @@
 # mt-aws-glacier - Amazon Glacier sync client
-# Copyright (C) 2012-2014  Victor Efimov
+# Copyright (C) 2012-2013  Victor Efimov
 # http://mt-aws.com (also http://vs-dev.com) vs@vs-dev.com
 # License: GPLv3
 #
@@ -20,7 +20,7 @@
 
 package App::MtAws::HttpWriter;
 
-our $VERSION = '1.114_2';
+our $VERSION = '1.050';
 
 use strict;
 use warnings;
@@ -103,13 +103,13 @@ sub finish
 
 package App::MtAws::HttpSegmentWriter;
 
-our $VERSION = '1.114_2';
+our $VERSION = '1.050';
 
 use strict;
 use warnings;
 use utf8;
 use App::MtAws::Utils;
-use Fcntl qw/SEEK_SET LOCK_EX/;
+use Fcntl qw/SEEK_SET LOCK_EX LOCK_UN/;
 use Carp;
 use base qw/App::MtAws::HttpWriter/;
 
@@ -161,7 +161,8 @@ sub _flush
 		$fh->autoflush(1);
 		seek $fh, $self->{position}+$self->{incr_position}, SEEK_SET or delayed_confess "cannot seek() $!";
 		$self->{incr_position} += $self->_flush_buffers($fh);
-		close $fh or delayed_confess; # close will unlock
+		flock $fh, LOCK_UN or delayed_confess;
+		close $fh or delayed_confess;
 	}
 }
 
@@ -175,12 +176,13 @@ sub finish
 
 package App::MtAws::HttpFileWriter;
 
-our $VERSION = '1.114_2';
+our $VERSION = '1.050';
 
 use strict;
 use warnings;
 use utf8;
 use App::MtAws::Utils;
+use Fcntl qw/SEEK_SET LOCK_EX LOCK_UN/;
 use Carp;
 use base qw/App::MtAws::HttpWriter/;
 
@@ -232,7 +234,7 @@ sub finish
 
 package App::MtAws::HttpMemoryWriter;
 
-our $VERSION = '1.114_2';
+our $VERSION = '1.050';
 
 use strict;
 use warnings;
