@@ -1,5 +1,5 @@
 # mt-aws-glacier - Amazon Glacier sync client
-# Copyright (C) 2012-2014  Victor Efimov
+# Copyright (C) 2012-2013  Victor Efimov
 # http://mt-aws.com (also http://vs-dev.com) vs@vs-dev.com
 # License: GPLv3
 #
@@ -20,15 +20,15 @@
 
 package App::MtAws::Journal;
 
-our $VERSION = '1.114_2';
+our $VERSION = '1.050';
 
 use strict;
 use warnings;
 use utf8;
 
 
-use File::Find;
-use File::Spec 3.12;
+use File::Find ;
+use File::Spec;
 use Encode;
 use Carp;
 use IO::Handle;
@@ -51,12 +51,6 @@ sub new
 
 	$self->{journal_encoding} ||= 'UTF-8';
 
-	if (defined $self->{root_dir}) {
-		# copied from File::Spec::catfile
-		$self->{canon_root_dir} = File::Spec->catdir($self->{root_dir});
-		$self->{canon_root_dir} .= "/" unless substr($self->{canon_root_dir},-1) eq "/";
-	}
-
 	defined($self->{journal_file}) || confess;
 	$self->{journal_h} = {};
 	$self->{archive_h} = {};
@@ -158,7 +152,7 @@ sub process_line
 		});
 		$self->{used_versions}->{$ver} = 1 unless $self->{used_versions}->{$ver};
 	} elsif (($ver, $time, $archive_id, $relfilename) = $line =~ /^([ABC])\t([0-9]{1,20})\tDELETED\t(\S+)\t(.*?)$/) {
-		$self->_delete_archive($archive_id, $relfilename);
+		$self->_delete_archive($archive_id); # TODO avoid stuff like $1 $2 $3 etc
 		$self->{used_versions}->{$ver} = 1 unless $self->{used_versions}->{$ver};
 	} elsif (($ver, $time, $archive_id, $job_id) = $line =~ /^([ABC])\t([0-9]{1,20})\tRETRIEVE_JOB\t(\S+)\t(.*?)$/) {
 		$self->_retrieve_job($time+0, $archive_id, $job_id);
@@ -178,8 +172,8 @@ sub process_line
 			treehash => $treehash,
 		});
 		$self->{used_versions}->{0} = 1 unless $self->{used_versions}->{0};
-	} elsif (($archive_id, $relfilename) = $line =~ /^[0-9]{1,20}\s+DELETED\s+(\S+)\s+(.*?)$/) { # TODO: delete file, parse time too!
-		$self->_delete_archive($archive_id, $relfilename);
+	} elsif ($line =~ /^[0-9]{1,20}\s+DELETED\s+(\S+)\s+(.*?)$/) { # TODO: delete file, parse time too!
+		$self->_delete_archive($1);
 		$self->{used_versions}->{0} = 1 unless $self->{used_versions}->{0};
 	} elsif (($time, $archive_id) = $line =~ /^([0-9]{1,20})\s+RETRIEVE_JOB\s+(\S+)$/) {
 		$self->_retrieve_job($time+0, $archive_id);
@@ -199,7 +193,7 @@ sub process_line
 sub _add_archive
 {
 	my ($self, $args) = @_;
-	if ($self->check_filenames($args->{relfilename})) {
+	if (!$self->{filter} || $self->{filter}->check_filenames($args->{relfilename})) {
 		confess "duplicate entry" if $self->{archive_h}{$args->{archive_id}};
 		$self->{archive_h}{$args->{archive_id}} = $args;
 	}
@@ -207,15 +201,9 @@ sub _add_archive
 
 sub _delete_archive
 {
-	my ($self, $archive_id, $relfilename) = @_;
-	confess unless defined $archive_id && defined $relfilename;
-
-	if ($self->{archive_h}{$archive_id}) {
-		delete $self->{archive_h}{$archive_id}; # archive_id found, deleting it without checking filename filter
-	} else {
-		confess "archive $archive_id not found in archive_h" # not found - confess, unless it's excluded by filter
-			if $self->check_filenames($relfilename); # TODO: put it to backlog, process later?
-	}
+	my ($self, $archive_id) = @_;
+	$self->{archive_h}{$archive_id} or confess "archive $archive_id not found in archive_h"; # TODO: put it to backlog, process later?
+	delete $self->{archive_h}{$archive_id};
 }
 
 sub _add_filename
@@ -304,7 +292,6 @@ sub _write_line
 # Reading file listing
 #
 
-
 sub read_files
 {
 	my ($self, $mode, $max_number_of_files) = @_;
@@ -322,7 +309,6 @@ sub read_files
 	# TODO: find better workaround than "-s"
 	$File::Find::prune = 0;
 	$File::Find::dont_use_nlink = !$self->{leaf_optimization};
-
 	File::Find::find({ wanted => sub {
 		if ($self->_listing_exceeed_max_number_of_files($max_number_of_files)) {
 			$File::Find::prune = 1;
@@ -339,8 +325,7 @@ sub read_files
 
 		if (-d) {
 			my $dir = character_filename($_);
-			$dir =~ s!/$!!; # make sure there is no trailing slash. just in case.
-			my $reldir = abs2rel($dir, $self->{root_dir}, allow_rel_base => 1);
+			my $reldir = File::Spec->abs2rel($dir, $self->{root_dir});
 			if ($self->{filter} && $reldir ne '.') {
 				my ($match, $matchsubdirs) = $self->{filter}->check_dir($reldir."/");
 				if (!$match && $matchsubdirs) {
@@ -350,8 +335,8 @@ sub read_files
 		} else {
 			# file can be not existing here (i.e. dangling symlink)
 			my $filename = character_filename(my $binaryfilename = $_);
-			my $orig_relfilename = abs2rel($filename, $self->{root_dir}, allow_rel_base => 1);
-			if ($self->check_filenames($orig_relfilename)) {
+			my $orig_relfilename = File::Spec->abs2rel($filename, $self->{root_dir});
+			if (!$self->{filter} || $self->{filter}->check_filenames($orig_relfilename)) {
 				if ($self->_is_file_exists($binaryfilename)) {
 					my $relfilename;
 					confess "Invalid filename: ".hex_dump_string($orig_relfilename)
@@ -407,12 +392,8 @@ sub _is_file_exists
 sub absfilename
 {
 	my ($self, $relfilename) = @_;
-	confess unless defined($self->{canon_root_dir});
-
-	# Originally it was: File::Spec->rel2abs($relfilename, $self->{root_dir});
-
-	# TODO: maybe add File::Spec->canonpath() and fix absfilename_correct=./dirA/file3 ?
-	$self->{canon_root_dir}.$relfilename;
+	confess unless defined($self->{root_dir});
+	return File::Spec->rel2abs($relfilename, $self->{root_dir});
 }
 
 
@@ -441,10 +422,6 @@ sub _can_read_filename_for_mode
 	}
 }
 
-sub check_filenames
-{
-	my $self = shift;
-	!$self->{filter} || $self->{filter}->check_filenames(@_)
-}
+
 
 1;
