@@ -1,5 +1,5 @@
 # mt-aws-glacier - Amazon Glacier sync client
-# Copyright (C) 2012-2014  Victor Efimov
+# Copyright (C) 2012-2013  Victor Efimov
 # http://mt-aws.com (also http://vs-dev.com) vs@vs-dev.com
 # License: GPLv3
 #
@@ -20,7 +20,7 @@
 
 package App::MtAws::LineProtocol;
 
-our $VERSION = '1.114_2';
+our $VERSION = '1.050';
 
 use strict;
 use warnings;
@@ -30,7 +30,8 @@ use Carp;
 use JSON::XS;
 use App::MtAws::Utils;
 
-use Exporter 'import';
+require Exporter;
+use base qw/Exporter/;
 
 our @EXPORT = qw/ get_data send_data/;
 our @EXPORT_OK = qw/escape unescape encode_data decode_data/;
@@ -57,17 +58,17 @@ sub get_data
 
 	my ($len, $line);
 
-	sysreadfull_chk($fh, $len, 8) &&
-	sysreadfull_chk($fh, $line, $len+0) or
+	sysreadfull($fh, $len, 8) &&
+	sysreadfull($fh, $line, $len+0) or
 	return;
 
 	chomp $line;
 	my ($pid, $action, $taskid, $datasize, $attachmentsize) = split /\t/, $line;
-	sysreadfull_chk($fh, my $data_e, $datasize) or
+	sysreadfull($fh, my $data_e, $datasize) or
 		return;
 	my $attachment = undef;
 	if ($attachmentsize) {
-		sysreadfull_chk($fh, $attachment, $attachmentsize) or
+		sysreadfull($fh, $attachment, $attachmentsize) or
 			return;
 	}
 	my $data = decode_data($data_e);
@@ -87,10 +88,10 @@ sub send_data
 	my $datasize = length($data_e);
 	my $line = "$$\t$action\t$taskid\t$datasize\t$attachmentsize\n"; # encode_data returns ASCII-7bit data, so ok here
 	confess if is_wide_string($line);
-	syswritefull_chk($fh, sprintf("%08d", length($line))) &&
-	syswritefull_chk($fh, $line) &&
-	syswritefull_chk($fh, $data_e) &&
-		(!$attachmentsize || syswritefull_chk($fh, $$attachmentref)) or
+	syswritefull($fh, sprintf("%08d", length($line))) &&
+	syswritefull($fh, $line) &&
+	syswritefull($fh, $data_e) &&
+		(!$attachmentsize || syswritefull($fh, $$attachmentref)) or
 		return;
 	return 1;
 }
