@@ -1,5 +1,5 @@
 # mt-aws-glacier - Amazon Glacier sync client
-# Copyright (C) 2012-2014  Victor Efimov
+# Copyright (C) 2012-2013  Victor Efimov
 # http://mt-aws.com (also http://vs-dev.com) vs@vs-dev.com
 # License: GPLv3
 #
@@ -20,7 +20,7 @@
 
 package App::MtAws::MetaData;
 
-our $VERSION = '1.114_2';
+our $VERSION = '1.050';
 
 use strict;
 use warnings;
@@ -31,14 +31,9 @@ use MIME::Base64;
 use JSON::XS;
 use POSIX;
 use Time::Local;
-use App::MtAws::DateTime;
 
 use constant MAX_SIZE => 1024;
-use constant META_JOB_TYPE_FULL => 'full';
 
-use Exporter 'import';
-
-our @EXPORT = qw/meta_decode meta_job_decode meta_encode meta_job_encode META_JOB_TYPE_FULL/;
 =pod
 
 MT-AWS-GLACIER metadata format ('x-amz-archive-description' field).
@@ -56,9 +51,8 @@ latin1_to_utf8() - input - byte sequence, output - byte sequence
 	Treats input data as Latin1 (ISO 8859-1) encoded sequence and converts it to UTF-8 sequence
 
 isoO8601() - input - time, output - character string
-	ISOO8601 time in the following format YYYYMMDDTHHMMSSZ. Only UTC timezone. No leap seconds supported.
-	Supported year range is from 1000 to 9999
-	When encoding isoO8601() mt-aws-glacier will not store leap seconds. When decoding from isoO8601 leap seconds will be dropped.
+	ISOO8601 time in the following format YYYYMMDDTHHMMSSZ. Only UTC filezone. No leap seconds supported.
+	When encoding isoO8601() mt-aws-glacier will not store leap seconds. When decoding from isoO8601 leap seconds are not supported (yet).
 
 {'filename': FILENAME, 'mtime': iso8601(MTIME)}
 	Hash with two keys: 'filename' and 'mtime'. Corresponds to JSON 'Object'.
@@ -71,8 +65,8 @@ FILENAME (character string)
 	with known encoding.
 MTIME (time)
 	is file last modification time with 1 second resolution. Can be below Y1970.
-	Internal representation is epoch time, so it can be any valid epoch time (including negative values and zero).Supported
-	range - from year 1000 to 9999 (inclusive)
+	Internal representation is epoch time, so it can be any valid epoch time (including negative values and zero). On some system it's
+	32bit signed, on others 64bit signed, for some filesystems it's 34 bit signed etc.
 
 Version 'mt2'
 =====================
@@ -106,108 +100,71 @@ understant how to decode it back.
 
 =cut
 
-my $meta_coder = ($JSON::XS::VERSION ge '1.4') ?
+my $meta_coder = ($JSON::XS::VERSION >= 1.4) ?
 	JSON::XS->new->utf8->max_depth(1)->max_size(MAX_SIZE) : # some additional abuse-protection
 	JSON::XS->new->utf8; # it's still protected by length checking below
 
 sub meta_decode
 {
 	my ($str) = @_;
-	return unless defined $str; # protect from undef $str
-
-	my ($marker, $b64) = _split_meta($str);
-	return unless defined $marker;
+	my ($marker, $b64) = split(' ', $str);
 	if ($marker eq 'mt1') {
-		return _decode_filename_and_mtime(_decode_json(_decode_utf8(_decode_b64($b64))));
+		return (undef, undef) unless length($b64) <= MAX_SIZE;
+		return _decode_json(_decode_utf8(_decode_b64($b64)));
 	} elsif ($marker eq 'mt2') {
-		return _decode_filename_and_mtime(_decode_json(_decode_b64($b64)));
+		return (undef, undef) unless length($b64) <= MAX_SIZE;
+		return _decode_json(_decode_b64($b64));
 	} else {
-		return;
+		return (undef, undef);
 	}
 }
 
-sub meta_job_decode
-{
-	my ($str) = @_;
-	return unless defined $str; # protect from undef $str
-
-	my ($marker, $b64) = _split_meta($str);
-	return unless defined $marker;
-	if ($marker eq 'mtijob1') {
-		_decode_jobs(_decode_json(_decode_b64($b64)));
-	} else {
-		return;
-	}
-}
-
-sub _split_meta
-{
-	my ($str) = @_;
-	my ($marker, $b64) = split(' ', $str); # split will return empty list if string is empty or contains spaces only
-	return if !defined $b64 || length($b64) > MAX_SIZE;
-	return ($marker, $b64);
-}
-
 sub _decode_b64
 {
 	my ($str) = @_;
-	return eval {
+	my $res = eval {
 		$str =~ tr{-_}{+/};
 		my $padding_n = length($str) % 4;
 		$str .= ('=' x (4 - $padding_n) ) if $padding_n;
 		MIME::Base64::decode_base64($str);
-	}; # undef if eval failed
+	};
+	return $@ eq '' ? $res : undef;
 }
 
 sub _decode_utf8
 {
 	my ($str) = @_;
 	return unless defined $str;
-	return eval {
+	my $res = eval {
 		decode("UTF-8", $str, Encode::DIE_ON_ERR|Encode::LEAVE_SRC)
-	};  # undef if eval failed
+	};
+	return $@ eq '' ? $res : undef;
 }
 
 sub _decode_json
 {
 	my ($str) = @_;
 	return unless defined $str;
-	eval { $meta_coder->decode($str) }
+	my $h = eval {
+		$meta_coder->decode($str)
+	};
+	if ($@ ne '') {
+		return (undef, undef);
+	} else {
+		return (undef, undef) unless defined($h->{filename}) && defined($h->{mtime});
+		my $mtime = _parse_iso8601($h->{mtime});
+		return unless defined $mtime;
+		return ($h->{filename}, $mtime);
+	}
 }
 
-sub _decode_filename_and_mtime
-{
-	my ($h) = @_;
-	return unless defined $h;
-	return unless defined($h->{filename}) && defined($h->{mtime});
-	 # TODO: is that good to return undef everytime something missing? Maybe return error in case signature etc
-	 # correct but time is broken - it's more robust.
-	defined(my $mtime = iso8601_to_epoch($h->{mtime})) or return;
-	return ($h->{filename}, $mtime);
-}
 
-sub _decode_jobs
-{
-	my ($h) = @_;
-	return unless defined $h;
-	return unless defined($h->{type});
-	return ($h->{type});
-}
 
 sub meta_encode
 {
 	my ($relfilename, $mtime) = @_;
 	return unless defined($mtime) && defined($relfilename);
-	defined(my $res = _encode_b64(_encode_json(_encode_filename_and_mtime($relfilename, $mtime)))) or return;
-	$res = "mt2 ".$res;
-	return if length($res) > MAX_SIZE;
-	return $res;
-}
-
-sub meta_job_encode
-{
-	my ($type) = @_;
-	my $res = "mtijob1 "._encode_b64(_encode_json({ type => $type }));
+	my $res = "mt2 "._encode_b64(_encode_json($relfilename, $mtime));
 	return if length($res) > MAX_SIZE;
 	return $res;
 }
@@ -215,7 +172,6 @@ sub meta_job_encode
 sub _encode_b64
 {
 	my ($str) = @_;
-	return unless defined $str;
 	my $res = MIME::Base64::encode_base64($str,'');
 	$res =~ s/=+\z//;
 	$res =~ tr{+/}{-_};
@@ -228,21 +184,25 @@ sub _encode_utf8
 	return encode("UTF-8",$str,Encode::DIE_ON_ERR|Encode::LEAVE_SRC);
 }
 
-sub _encode_filename_and_mtime
-{
-	my ($relfilename, $mtime) = @_;
-	defined(my $iso = epoch_to_iso8601($mtime)) or return;
-	return {
-		mtime => $iso,
-		filename => $relfilename
-	};
-}
 
 sub _encode_json
 {
-	my ($h) = @_;
-	return unless defined $h;
-	return $meta_coder->encode($h);
+	my ($relfilename, $mtime) = @_;
+
+	return $meta_coder->encode({
+		mtime => strftime("%Y%m%dT%H%M%SZ", gmtime($mtime)),
+		filename => $relfilename
+	}),
+}
+
+sub _parse_iso8601 # Implementing this as I don't want to have non-core dependencies
+{
+	my ($str) = @_;
+	return unless $str =~ /^\s*(\d{4})[\-\s]*(\d{2})[\-\s]*(\d{2})\s*T\s*(\d{2})[\:\s]*(\d{2})[\:\s]*(\d{2})[\,\.\d]{0,10}\s*Z\s*$/i; # _some_ iso8601 support for now
+	my ($year, $month, $day, $hour, $min, $sec) = ($1,$2,$3,$4,$5,$6);
+	$sec = 59 if $sec == 60; # TODO: dirty workaround to avoid dealing with leap seconds
+	my $res = eval { timegm($sec,$min,$hour,$day,$month - 1,$year) };
+	return ($@ ne ' ') ? $res : undef;
 }
 
 1;
