@@ -1,5 +1,5 @@
 # mt-aws-glacier - Amazon Glacier sync client
-# Copyright (C) 2012-2014  Victor Efimov
+# Copyright (C) 2012-2013  Victor Efimov
 # http://mt-aws.com (also http://vs-dev.com) vs@vs-dev.com
 # License: GPLv3
 #
@@ -20,7 +20,7 @@
 
 package App::MtAws::ParentWorker;
 
-our $VERSION = '1.114_2';
+our $VERSION = '1.050';
 
 use strict;
 use warnings;
@@ -29,60 +29,78 @@ use App::MtAws::LineProtocol;
 use Carp;
 use POSIX;
 use App::MtAws::Utils;
-use base q{App::MtAws::QueueEngine};
 
-sub init
+sub new
 {
-	my ($self, %args) = @_;
-	$self->{$_} = $args{$_} || confess for (qw/children disp_select options/);
-	$self->add_worker($_) for (keys %{$self->{children}});
+	my ($class, %args) = @_;
+	my $self = \%args;
+	$self->{children}||die;
+	$self->{disp_select}||die;
+	$self->{options}||die;
+	@{$self->{freeworkers}} = keys %{$self->{children}};
+	bless $self, $class;
+	return $self;
 }
 
-sub queue
+sub process_task
 {
-	my ($self, $worker_id, $task) = @_;
-	my $worker = $self->{children}{$worker_id};
-	send_data($worker->{tochild}, $task->{action}, $task->{_id}, $task->{args}, $task->{attachment}) or
-		$self->comm_error;
-
+	my ($self, $ft, $journal) = @_;
+	my $task_list = {};
+	while () {
+		if ( @{$self->{freeworkers}} ) {
+			my ($result, $task) = $ft->get_task();
+			if ($result eq 'wait') {
+				if (scalar keys %{$self->{children}} == scalar @{$self->{freeworkers}}) {
+					die;
+				}
+				my ($r, $att) = $self->wait_worker($task_list, $ft, $journal);
+				return ($r, $att) if $r;
+			} elsif ($result eq 'ok') {
+				my $worker_pid = shift @{$self->{freeworkers}};
+				my $worker = $self->{children}->{$worker_pid};
+				$task_list->{$task->{id}} = $task;
+				send_data($worker->{tochild}, $task->{action}, $task->{id}, $task->{data}, $task->{attachment}) or
+					$self->comm_error;
+			} elsif ($result eq 'done') {
+				return (1, undef);
+			} else {
+				die;
+			}
+		} else {
+			my ($r, $att) = $self->wait_worker($task_list, $ft, $journal);
+			return ($r, $att) if $r;
+		}
+	}
 }
 
 sub wait_worker
 {
-	my ($self) = @_;
+	my ($self, $task_list, $ft, $journal) = @_;
 	my @ready;
 	do { @ready = $self->{disp_select}->can_read(); } until @ready || $! != EINTR;
 	for my $fh (@ready) {
 		my ($pid, undef, $taskid, $data, $resultattachmentref) = get_data($fh);
 		$pid or $self->comm_error;
-
-		my $task = $self->unqueue_task($pid);
-
-		confess unless $taskid == $task->{_id};
-
+		push @{$self->{freeworkers}}, $pid;
+		die unless my $task = $task_list->{$taskid};
 		$task->{result} = $data;
 		$task->{attachmentref} = $resultattachmentref;
+		print "PID $pid $task->{result}->{console_out}\n";
+		if ($task->{result}->{journal_entry}) {
+			confess unless defined $journal;
+			$journal->add_entry($task->{result}->{journal_entry});
+		}
 
-		print "PID $pid $data->{console_out}\n";
+		delete $task_list->{$taskid};
+		my ($result) = $ft->finish_task($task);
 
-		$task->{cb_task_proxy}->($data, $resultattachmentref);
-
-		if ($data->{journal_entry}) {
-			confess unless defined $self->{journal};
-			$self->{journal}->add_entry($data->{journal_entry});
+		if ($result eq 'done') {
+			return ($task->{result}, $task->{attachmentref});
 		}
-		return;
 	}
 	return 0;
 }
 
-sub process_task
-{
-	my ($self, $lt, $j) = @_;
-	$self->{journal} = $j;
-	$self->process($lt);
-}
-
 sub comm_error
 {
 	my ($self) = @_;
