@@ -1,5 +1,5 @@
 # mt-aws-glacier - Amazon Glacier sync client
-# Copyright (C) 2012-2014  Victor Efimov
+# Copyright (C) 2012-2013  Victor Efimov
 # http://mt-aws.com (also http://vs-dev.com) vs@vs-dev.com
 # License: GPLv3
 #
@@ -20,46 +20,25 @@
 
 package App::MtAws::Utils;
 
-our $VERSION = '1.114_2';
+our $VERSION = '1.050';
 
 use strict;
 use warnings;
 use utf8;
 use File::Spec;
-use Cwd;
 use File::stat;
 use Carp;
 use Encode;
 use LWP::UserAgent;
-use Time::Local;
-use Config;
 use bytes ();
 
-use Exporter 'import';
+require Exporter;
+use base qw/Exporter/;
 
-use constant INVENTORY_TYPE_CSV => 'CSV';
-use constant INVENTORY_TYPE_JSON => 'JSON';
 
 our @EXPORT = qw/set_filename_encoding get_filename_encoding binaryfilename
-sanity_relative_filename is_relative_filename abs2rel binary_abs_path open_file sysreadfull syswritefull sysreadfull_chk syswritefull_chk
-hex_dump_string is_wide_string
-characterfilename try_drop_utf8_flag dump_request_response file_size file_mtime file_exists file_inodev
-is_64bit_os is_64bit_time is_y2038_supported
-INVENTORY_TYPE_JSON INVENTORY_TYPE_CSV/;
-
-
-BEGIN {
-	if ($File::Spec::VERSION lt '3.13') {
-		our $__orig_abs_to_rel = File::Spec->can("abs2rel");
-		no warnings 'once';
-		*File::Spec::abs2rel = sub {
-			my $r = $__orig_abs_to_rel->(@_);
-			return '.' if $r eq '';
-			$r;
-		};
-	}
-}
-
+sanity_relative_filename is_relative_filename open_file sysreadfull syswritefull hex_dump_string
+is_wide_string characterfilename try_drop_utf8_flag dump_request_response file_size file_mtime file_exists/;
 
 # Does not work with directory names
 sub sanity_relative_filename
@@ -70,9 +49,7 @@ sub sanity_relative_filename
 	$filename =~ s!^/!!;
 	return undef if $filename =~ m![\r\n\t]!g;
 	$filename = File::Spec->catdir( map {return undef if m!^\.\.?$!; $_; } split('/', File::Spec->canonpath($filename)) );
-	return undef
-		if !defined($filename) ||  # workaround https://rt.cpan.org/Public/Bug/Display.html?id=86624
-			$filename eq '';
+	return undef if $filename eq '';
 	return $filename;
 }
 
@@ -87,25 +64,6 @@ sub is_relative_filename
 	1;
 }
 
-# TODO: test
-sub binary_abs_path
-{
-	my ($path) = @_;
-
-	local $SIG{__WARN__}=sub{};
-
-	my $orig_id = file_inodev($path, use_filename_encoding => 0);
-
-	my $abspath = Cwd::abs_path($path);
-
-	return undef unless defined $abspath;
-	return undef if $abspath eq ''; # workaround RT#47755
-
-	# workaround RT#47755 - in case perms problem it tries to return File::Spec->rel2abs
-	return undef unless -e $abspath && file_inodev($abspath, use_filename_encoding => 0) eq $orig_id;
-
-	return $abspath;
-}
 
 our $_filename_encoding = 'UTF-8'; # global var
 
@@ -122,22 +80,6 @@ sub characterfilename(;$)
 	decode(get_filename_encoding, @_ ? shift : $_, Encode::DIE_ON_ERR|Encode::LEAVE_SRC);
 }
 
-# TODO: test
-sub abs2rel
-{
-	my ($path, $base) = (shift, shift);
-	confess "too few arguments" unless defined($path) && defined($base);
-	my (%args) = (use_filename_encoding => 1, @_);
-	if ($args{use_filename_encoding}) {
-		$path = binaryfilename $path;
-		$base = binaryfilename $base;
-	}
-	$args{allow_rel_base} or $base =~ m{^/} or confess "relative basedir not allowed";
-	my $result = File::Spec->abs2rel($path, $base);
-	$args{use_filename_encoding} ? characterfilename($result) : $result;
-}
-
-
 =pod
 
 open_file(my $f, $filename, %args)
@@ -235,19 +177,6 @@ sub file_mtime($%)
 	return stat($filename)->mtime;
 }
 
-# TODO: test
-sub file_inodev($%)
-{
-	my $filename = shift;
-	my (%args) = (use_filename_encoding => 1, @_);
-	if ($args{use_filename_encoding}) {
-		$filename = binaryfilename $filename;
-	}
-	confess "file not exists" unless -e $filename;
-	my $s = stat($filename);
-	$s->dev."-".$s->ino;
-}
-
 sub is_wide_string
 {
 	defined($_[0]) && utf8::is_utf8($_[0]) && (bytes::length($_[0]) != length($_[0]))
@@ -260,12 +189,6 @@ sub try_drop_utf8_flag
 	Encode::_utf8_off($_[0]) if utf8::is_utf8($_[0]) && (bytes::length($_[0]) == length($_[0]));
 }
 
-sub sysreadfull_chk($$$)
-{
-	my $len = $_[2];
-	sysreadfull(@_) == $len;
-}
-
 sub sysreadfull($$$)
 {
 	my ($file, $len) = ($_[0], $_[2]);
@@ -287,12 +210,6 @@ sub sysreadfull($$$)
 	return $n;
 }
 
-sub syswritefull_chk($$)
-{
-	my $length = length $_[1];
-	syswritefull(@_) == $length
-}
-
 sub syswritefull($$)
 {
 	my ($file, $len) = ($_[0], length($_[1]));
@@ -357,37 +274,6 @@ sub dump_request_response
 	$out;
 }
 
-
-sub get_config_var($) # separate function so we can override it in tests
-{
-	$Config{shift()}
-}
-
-sub is_64bit_os
-{
-	get_config_var('longsize') >= 8
-}
-
-sub is_64bit_time
-{
-	is_64bit_os && ($^O =~ /^(freebsd|gnukfreebsd|netbsd|midnightbsd|linux|darwin|solaris)$/) # no OpenBSD for sure
-	# not sure about cygwin, solaris
-}
-
-
-our $_is_y2038_supported = undef;
-sub is_y2038_supported
-{
-	return $_is_y2038_supported if defined $_is_y2038_supported;
-	local $SIG{__WARN__} = sub {};
-	$_is_y2038_supported = eval {
-		(timegm(0, 0, 0, 01, 01, 2038) == 2148595200) &&
-		(timegm(0, 0, 0, 01, 01, 4000) == 64063267200) &&
-		(join(",",gmtime(64063267200)) eq "0,0,0,1,1,2100,2,31,0") &&
-		(join(",",gmtime(2148595200)) eq "0,0,0,1,1,138,1,31,0")
-	} || 0;
-}
-
 1;
 
 __END__
